@@ -256,85 +256,7 @@ static void release_buffer(struct AVCodecContext *context, AVFrame *av_frame){
 }
 #endif
 
-static const ff_codec_t ff_video_lookup[] = {
-  {BUF_VIDEO_MSMPEG4_V1,  CODEC_ID_MSMPEG4V1, "Microsoft MPEG-4 v1 (ffmpeg)"},
-  {BUF_VIDEO_MSMPEG4_V2,  CODEC_ID_MSMPEG4V2, "Microsoft MPEG-4 v2 (ffmpeg)"},
-  {BUF_VIDEO_MSMPEG4_V3,  CODEC_ID_MSMPEG4V3, "Microsoft MPEG-4 v3 (ffmpeg)"},
-  {BUF_VIDEO_WMV7,        CODEC_ID_WMV1,      "MS Windows Media Video 7 (ffmpeg)"},
-  {BUF_VIDEO_WMV8,        CODEC_ID_WMV2,      "MS Windows Media Video 8 (ffmpeg)"},
-  {BUF_VIDEO_WMV9,        CODEC_ID_WMV3,      "MS Windows Media Video 9 (ffmpeg)"},
-  {BUF_VIDEO_VC1,         CODEC_ID_VC1,       "MS Windows Media Video VC-1 (ffmpeg)"},
-  {BUF_VIDEO_MPEG4,       CODEC_ID_MPEG4,     "ISO MPEG-4 (ffmpeg)"},
-  {BUF_VIDEO_XVID,        CODEC_ID_MPEG4,     "ISO MPEG-4 (XviD, ffmpeg)"},
-  {BUF_VIDEO_DIVX5,       CODEC_ID_MPEG4,     "ISO MPEG-4 (DivX5, ffmpeg)"},
-  {BUF_VIDEO_3IVX,        CODEC_ID_MPEG4,     "ISO MPEG-4 (3ivx, ffmpeg)"},
-  {BUF_VIDEO_JPEG,        CODEC_ID_MJPEG,     "Motion JPEG (ffmpeg)"},
-  {BUF_VIDEO_MJPEG,       CODEC_ID_MJPEG,     "Motion JPEG (ffmpeg)"},
-  {BUF_VIDEO_MJPEG_B,     CODEC_ID_MJPEGB,    "Motion JPEG B (ffmpeg)"},
-  {BUF_VIDEO_I263,        CODEC_ID_H263I,     "ITU H.263 (ffmpeg)"},
-  {BUF_VIDEO_H263,        CODEC_ID_H263,      "H.263 (ffmpeg)"},
-  {BUF_VIDEO_RV10,        CODEC_ID_RV10,      "Real Video 1.0 (ffmpeg)"},
-  {BUF_VIDEO_RV20,        CODEC_ID_RV20,      "Real Video 2.0 (ffmpeg)"},
-  {BUF_VIDEO_IV31,        CODEC_ID_INDEO3,    "Indeo Video 3.1 (ffmpeg)"},
-  {BUF_VIDEO_IV32,        CODEC_ID_INDEO3,    "Indeo Video 3.2 (ffmpeg)"},
-  {BUF_VIDEO_SORENSON_V1, CODEC_ID_SVQ1,      "Sorenson Video 1 (ffmpeg)"},
-  {BUF_VIDEO_SORENSON_V3, CODEC_ID_SVQ3,      "Sorenson Video 3 (ffmpeg)"},
-  {BUF_VIDEO_DV,          CODEC_ID_DVVIDEO,   "DV (ffmpeg)"},
-  {BUF_VIDEO_HUFFYUV,     CODEC_ID_HUFFYUV,   "HuffYUV (ffmpeg)"},
-  {BUF_VIDEO_VP31,        CODEC_ID_VP3,       "On2 VP3.1 (ffmpeg)"},
-  {BUF_VIDEO_VP5,         CODEC_ID_VP5,       "On2 VP5 (ffmpeg)"},
-  {BUF_VIDEO_VP6,         CODEC_ID_VP6,       "On2 VP6 (ffmpeg)"},
-  {BUF_VIDEO_VP6F,        CODEC_ID_VP6F,      "On2 VP6 (ffmpeg)"},
-  {BUF_VIDEO_4XM,         CODEC_ID_4XM,       "4X Video (ffmpeg)"},
-  {BUF_VIDEO_CINEPAK,     CODEC_ID_CINEPAK,   "Cinepak (ffmpeg)"},
-  {BUF_VIDEO_MSVC,        CODEC_ID_MSVIDEO1,  "Microsoft Video 1 (ffmpeg)"},
-  {BUF_VIDEO_MSRLE,       CODEC_ID_MSRLE,     "Microsoft RLE (ffmpeg)"},
-  {BUF_VIDEO_RPZA,        CODEC_ID_RPZA,      "Apple Quicktime Video/RPZA (ffmpeg)"},
-  {BUF_VIDEO_CYUV,        CODEC_ID_CYUV,      "Creative YUV (ffmpeg)"},
-  {BUF_VIDEO_ROQ,         CODEC_ID_ROQ,       "Id Software RoQ (ffmpeg)"},
-  {BUF_VIDEO_IDCIN,       CODEC_ID_IDCIN,     "Id Software CIN (ffmpeg)"},
-  {BUF_VIDEO_WC3,         CODEC_ID_XAN_WC3,   "Xan (ffmpeg)"},
-  {BUF_VIDEO_VQA,         CODEC_ID_WS_VQA,    "Westwood Studios VQA (ffmpeg)"},
-  {BUF_VIDEO_INTERPLAY,   CODEC_ID_INTERPLAY_VIDEO, "Interplay MVE (ffmpeg)"},
-  {BUF_VIDEO_FLI,         CODEC_ID_FLIC,      "FLIC Video (ffmpeg)"},
-  {BUF_VIDEO_8BPS,        CODEC_ID_8BPS,      "Planar RGB (ffmpeg)"},
-  {BUF_VIDEO_SMC,         CODEC_ID_SMC,       "Apple Quicktime Graphics/SMC (ffmpeg)"},
-  {BUF_VIDEO_DUCKTM1,     CODEC_ID_TRUEMOTION1,"Duck TrueMotion v1 (ffmpeg)"},
-  {BUF_VIDEO_DUCKTM2,     CODEC_ID_TRUEMOTION2,"Duck TrueMotion v2 (ffmpeg)"},
-  {BUF_VIDEO_VMD,         CODEC_ID_VMDVIDEO,   "Sierra VMD Video (ffmpeg)"},
-  {BUF_VIDEO_ZLIB,        CODEC_ID_ZLIB,       "ZLIB Video (ffmpeg)"},
-  {BUF_VIDEO_MSZH,        CODEC_ID_MSZH,       "MSZH Video (ffmpeg)"},
-  {BUF_VIDEO_ASV1,        CODEC_ID_ASV1,       "ASV v1 Video (ffmpeg)"},
-  {BUF_VIDEO_ASV2,        CODEC_ID_ASV2,       "ASV v2 Video (ffmpeg)"},
-  {BUF_VIDEO_ATIVCR1,     CODEC_ID_VCR1,       "ATI VCR-1 (ffmpeg)"},
-  {BUF_VIDEO_FLV1,        CODEC_ID_FLV1,       "Flash Video (ffmpeg)"},
-  {BUF_VIDEO_QTRLE,       CODEC_ID_QTRLE,      "Apple Quicktime Animation/RLE (ffmpeg)"},
-  {BUF_VIDEO_H264,        CODEC_ID_H264,       "H.264/AVC (ffmpeg)"},
-  {BUF_VIDEO_H261,        CODEC_ID_H261,       "H.261 (ffmpeg)"},
-  {BUF_VIDEO_AASC,        CODEC_ID_AASC,       "Autodesk Video (ffmpeg)"},
-  {BUF_VIDEO_LOCO,        CODEC_ID_LOCO,       "LOCO (ffmpeg)"},
-  {BUF_VIDEO_QDRW,        CODEC_ID_QDRAW,      "QuickDraw (ffmpeg)"},
-  {BUF_VIDEO_QPEG,        CODEC_ID_QPEG,       "Q-Team QPEG (ffmpeg)"},
-  {BUF_VIDEO_TSCC,        CODEC_ID_TSCC,       "TechSmith Video (ffmpeg)"},
-  {BUF_VIDEO_ULTI,        CODEC_ID_ULTI,       "IBM UltiMotion (ffmpeg)"},
-  {BUF_VIDEO_WNV1,        CODEC_ID_WNV1,       "Winnow Video (ffmpeg)"},
-  {BUF_VIDEO_XL,          CODEC_ID_VIXL,       "Miro/Pinnacle VideoXL (ffmpeg)"},
-  {BUF_VIDEO_RT21,        CODEC_ID_INDEO2,     "Indeo/RealTime 2 (ffmpeg)"},
-  {BUF_VIDEO_FPS1,        CODEC_ID_FRAPS,      "Fraps (ffmpeg)"},
-  {BUF_VIDEO_MPEG,        CODEC_ID_MPEG1VIDEO, "MPEG 1/2 (ffmpeg)"},
-  {BUF_VIDEO_CSCD,        CODEC_ID_CSCD,       "CamStudio (ffmpeg)"},
-  {BUF_VIDEO_AVS,         CODEC_ID_AVS,        "AVS (ffmpeg)"},
-  {BUF_VIDEO_ALGMM,       CODEC_ID_MMVIDEO,    "American Laser Games MM (ffmpeg)"},
-  {BUF_VIDEO_ZMBV,        CODEC_ID_ZMBV,       "Zip Motion Blocks Video (ffmpeg)"},
-  {BUF_VIDEO_SMACKER,     CODEC_ID_SMACKVIDEO, "Smacker (ffmpeg)"},
-  {BUF_VIDEO_NUV,         CODEC_ID_NUV,        "NuppelVideo (ffmpeg)"},
-  {BUF_VIDEO_KMVC,        CODEC_ID_KMVC,       "Karl Morton's Video Codec (ffmpeg)"},
-  {BUF_VIDEO_FLASHSV,     CODEC_ID_FLASHSV,    "Flash Screen Video (ffmpeg)"},
-  {BUF_VIDEO_CAVS,        CODEC_ID_CAVS,       "Chinese AVS (ffmpeg)"},
-  {BUF_VIDEO_VMNC,        CODEC_ID_VMNC,       "VMware Screen Codec (ffmpeg)"},
-  {BUF_VIDEO_THEORA_RAW,  CODEC_ID_THEORA,     "Theora (ffmpeg)"},
-  {BUF_VIDEO_SNOW,        CODEC_ID_SNOW,       "Snow (ffmpeg)"},
-};
+#include "ff_video_list.h"
 
 static const char *const skip_loop_filter_enum_names[] = {
   "default", /* AVDISCARD_DEFAULT */
@@ -1808,237 +1730,6 @@ void *init_video_plugin (xine_t *xine, void *data) {
   return this;
 }
 
-static uint32_t supported_video_types[] = { 
-  #ifdef CONFIG_MSMPEG4V1_DECODER
-  BUF_VIDEO_MSMPEG4_V1,
-  #endif
-  #ifdef CONFIG_MSMPEG4V2_DECODER
-  BUF_VIDEO_MSMPEG4_V2,
-  #endif
-  #ifdef CONFIG_MSMPEG4V3_DECODER
-  BUF_VIDEO_MSMPEG4_V3,
-  #endif
-  #ifdef CONFIG_WMV1_DECODER
-  BUF_VIDEO_WMV7,
-  #endif
-  #ifdef CONFIG_WMV2_DECODER
-  BUF_VIDEO_WMV8,
-  #endif
-  #ifdef CONFIG_WMV3_DECODER
-  BUF_VIDEO_WMV9,
-  #endif
-  #ifdef CONFIG_VC1_DECODER
-  BUF_VIDEO_VC1,
-  #endif
-  #ifdef CONFIG_MPEG4_DECODER
-  BUF_VIDEO_MPEG4,
-  #endif
-  #ifdef CONFIG_MPEG4_DECODER
-  BUF_VIDEO_XVID,
-  #endif
-  #ifdef CONFIG_MPEG4_DECODER
-  BUF_VIDEO_DIVX5,
-  #endif
-  #ifdef CONFIG_MPEG4_DECODER
-  BUF_VIDEO_3IVX,
-  #endif
-  #ifdef CONFIG_MJPEG_DECODER
-  BUF_VIDEO_JPEG,
-  #endif
-  #ifdef CONFIG_MJPEG_DECODER
-  BUF_VIDEO_MJPEG,
-  #endif
-  #ifdef CONFIG_MJPEGB_DECODER
-  BUF_VIDEO_MJPEG_B,
-  #endif
-  #ifdef CONFIG_H263I_DECODER
-  BUF_VIDEO_I263,
-  #endif
-  #ifdef CONFIG_H263_DECODER
-  BUF_VIDEO_H263,
-  #endif
-  #ifdef CONFIG_RV10_DECODER
-  BUF_VIDEO_RV10,
-  #endif
-  #ifdef CONFIG_RV20_DECODER
-  BUF_VIDEO_RV20,
-  #endif
-  #ifdef CONFIG_INDEO3_DECODER
-  BUF_VIDEO_IV31,
-  #endif
-  #ifdef CONFIG_INDEO3_DECODER
-  BUF_VIDEO_IV32,
-  #endif
-  #ifdef CONFIG_SVQ1_DECODER
-  BUF_VIDEO_SORENSON_V1,
-  #endif
-  #ifdef CONFIG_SVQ3_DECODER
-  BUF_VIDEO_SORENSON_V3,
-  #endif
-  #ifdef CONFIG_DVVIDEO_DECODER
-  BUF_VIDEO_DV,
-  #endif
-  #ifdef CONFIG_HUFFYUV_DECODER
-  BUF_VIDEO_HUFFYUV,
-  #endif
-  #ifdef CONFIG_VP3_DECODER
-  BUF_VIDEO_VP31,
-  #endif
-  #ifdef CONFIG_VP5_DECODER
-  BUF_VIDEO_VP5,
-  #endif
-  #ifdef CONFIG_VP6_DECODER
-  BUF_VIDEO_VP6,
-  BUF_VIDEO_VP6F,
-  #endif
-  #ifdef CONFIG_4XM_DECODER
-  BUF_VIDEO_4XM,
-  #endif
-  #ifdef CONFIG_CINEPAK_DECODER
-  BUF_VIDEO_CINEPAK,
-  #endif
-  #ifdef CONFIG_MSVIDEO1_DECODER
-  BUF_VIDEO_MSVC,
-  #endif
-  #ifdef CONFIG_MSRLE_DECODER
-  BUF_VIDEO_MSRLE,
-  #endif
-  #ifdef CONFIG_RPZA_DECODER
-  BUF_VIDEO_RPZA,
-  #endif
-  #ifdef CONFIG_CYUV_DECODER
-  BUF_VIDEO_CYUV,
-  #endif
-  #ifdef CONFIG_ROQ_DECODER
-  BUF_VIDEO_ROQ,
-  #endif
-  #ifdef CONFIG_IDCIN_DECODER
-  BUF_VIDEO_IDCIN,
-  #endif
-  #ifdef CONFIG_XAN_WC3_DECODER
-  BUF_VIDEO_WC3,
-  #endif
-  #ifdef CONFIG_WS_VQA_DECODER
-  BUF_VIDEO_VQA,
-  #endif
-  #ifdef CONFIG_INTERPLAY_VIDEO_DECODER
-  BUF_VIDEO_INTERPLAY,
-  #endif
-  #ifdef CONFIG_FLIC_DECODER
-  BUF_VIDEO_FLI,
-  #endif
-  #ifdef CONFIG_8BPS_DECODER
-  BUF_VIDEO_8BPS,
-  #endif
-  #ifdef CONFIG_SMC_DECODER
-  BUF_VIDEO_SMC,
-  #endif
-  #ifdef CONFIG_TRUEMOTION1_DECODER
-  BUF_VIDEO_DUCKTM1,
-  #endif
-  #ifdef CONFIG_TRUEMOTION2_DECODER
-  BUF_VIDEO_DUCKTM2,
-  #endif
-  #ifdef CONFIG_VMDVIDEO_DECODER
-  BUF_VIDEO_VMD,
-  #endif
-  #ifdef CONFIG_ZLIB_DECODER
-  BUF_VIDEO_ZLIB,
-  #endif
-  #ifdef CONFIG_MSZH_DECODER
-  BUF_VIDEO_MSZH,
-  #endif
-  #ifdef CONFIG_ASV1_DECODER
-  BUF_VIDEO_ASV1,
-  #endif
-  #ifdef CONFIG_ASV2_DECODER
-  BUF_VIDEO_ASV2,
-  #endif
-  #ifdef CONFIG_VCR1_DECODER
-  BUF_VIDEO_ATIVCR1,
-  #endif
-  #ifdef CONFIG_FLV_DECODER
-  BUF_VIDEO_FLV1,
-  #endif
-  #ifdef CONFIG_QTRLE_DECODER
-  BUF_VIDEO_QTRLE,
-  #endif
-  #ifdef CONFIG_H264_DECODER
-  BUF_VIDEO_H264,
-  #endif
-  #ifdef CONFIG_H261_DECODER
-  BUF_VIDEO_H261,
-  #endif
-  #ifdef CONFIG_AASC_DECODER
-  BUF_VIDEO_AASC,
-  #endif
-  #ifdef CONFIG_LOCO_DECODER
-  BUF_VIDEO_LOCO,
-  #endif
-  #ifdef CONFIG_QDRAW_DECODER
-  BUF_VIDEO_QDRW,
-  #endif
-  #ifdef CONFIG_QPEG_DECODER
-  BUF_VIDEO_QPEG,
-  #endif
-  #ifdef CONFIG_TSCC_DECODER
-  BUF_VIDEO_TSCC,
-  #endif
-  #ifdef CONFIG_ULTI_DECODER
-  BUF_VIDEO_ULTI,
-  #endif
-  #ifdef CONFIG_WNV1_DECODER
-  BUF_VIDEO_WNV1,
-  #endif
-  #ifdef CONFIG_VIXL_DECODER
-  BUF_VIDEO_XL,
-  #endif
-  #ifdef CONFIG_INDEO2_DECODER
-  BUF_VIDEO_RT21,
-  #endif
-  #ifdef CONFIG_FRAPS_DECODER
-  BUF_VIDEO_FPS1,
-  #endif
-  #ifdef CONFIG_MPEG1VIDEO_DECODER
-  BUF_VIDEO_MPEG,
-  #endif
-  #ifdef CONFIG_CSCD_DECODER
-  BUF_VIDEO_CSCD,
-  #endif
-  #ifdef CONFIG_AVS_DECODER
-  BUF_VIDEO_AVS,
-  #endif
-  #ifdef CONFIG_MMVIDEO_DECODER
-  BUF_VIDEO_ALGMM,
-  #endif
-  #ifdef CONFIG_ZMBV_DECODER
-  BUF_VIDEO_ZMBV,
-  #endif
-  #ifdef CONFIG_SMACKVIDEO_DECODER
-  BUF_VIDEO_SMACKER,
-  #endif
-  #ifdef CONFIG_NUV_DECODER
-  BUF_VIDEO_NUV,
-  #endif
-  #ifdef CONFIG_KMVC_DECODER
-  BUF_VIDEO_KMVC,
-  #endif
-  #ifdef CONFIG_FLASHSV_DECODER
-  BUF_VIDEO_FLASHSV,
-  #endif
-  #ifdef CONFIG_CAVS_DECODER
-  BUF_VIDEO_CAVS,
-  #endif
-  #ifdef CONFIG_VMNC_DECODER
-  BUF_VIDEO_VMNC,
-  #endif
-  #ifdef CONFIG_SNOW_DECODER
-  BUF_VIDEO_SNOW,
-  #endif
-  BUF_VIDEO_THEORA_RAW,
-  0 
-};
-
 static uint32_t wmv8_video_types[] = { 
   BUF_VIDEO_WMV8,
   0 
