@@ -15,9 +15,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
- *
- * $Id: video_out_dxr3.c,v 1.106 2004/12/12 22:01:04 mroi Exp $
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
  */
  
 /* mpeg1 encoding video out plugin for the dxr3.  
@@ -65,7 +63,6 @@
 #include "xine_internal.h"
 #include "xineutils.h"
 #include "video_out.h"
-#include "alphablend.h"
 #include "dxr3.h"
 #include "video_out_dxr3.h"
 
@@ -81,23 +78,23 @@ static dxr3_driver_class_t *dxr3_vo_init_plugin(xine_t *xine, void *visual_gen);
 
 /* plugin catalog information */
 #ifdef HAVE_X11
-static vo_info_t   vo_info_dxr3_x11 = {
+static const vo_info_t   vo_info_dxr3_x11 = {
   10,                  /* priority        */
   XINE_VISUAL_TYPE_X11 /* visual type     */
 };
 #endif
 
-static vo_info_t   vo_info_dxr3_aa = {
+static const vo_info_t   vo_info_dxr3_aa = {
   10,                  /* priority        */
   XINE_VISUAL_TYPE_AA  /* visual type     */
 };
 
-plugin_info_t      xine_plugin_info[] = {
+const plugin_info_t      xine_plugin_info[] EXPORTED = {
   /* type, API, "name", version, special_info, init_function */  
 #ifdef HAVE_X11
-  { PLUGIN_VIDEO_OUT, 20, "dxr3", XINE_VERSION_CODE, &vo_info_dxr3_x11, &dxr3_x11_init_plugin },
+  { PLUGIN_VIDEO_OUT, 21, "dxr3", XINE_VERSION_CODE, &vo_info_dxr3_x11, &dxr3_x11_init_plugin },
 #endif
-  { PLUGIN_VIDEO_OUT, 20, "aadxr3", XINE_VERSION_CODE, &vo_info_dxr3_aa, &dxr3_aa_init_plugin },
+  { PLUGIN_VIDEO_OUT, 21, "aadxr3", XINE_VERSION_CODE, &vo_info_dxr3_aa, &dxr3_aa_init_plugin },
   { PLUGIN_NONE, 0, "", 0, NULL, NULL }
 };
 
@@ -172,7 +169,7 @@ static dxr3_driver_class_t *dxr3_vo_init_plugin(xine_t *xine, void *visual_gen)
 {
   dxr3_driver_class_t *this;
   
-  this = (dxr3_driver_class_t *)xine_xmalloc(sizeof(dxr3_driver_class_t));
+  this = calloc(1, sizeof(dxr3_driver_class_t));
   if (!this) return NULL;
   
   this->devnum = xine->config->register_num(xine->config,
@@ -222,17 +219,20 @@ static vo_driver_t *dxr3_vo_open_plugin(video_driver_class_t *class_gen, const v
   int encoder, confnum;
   static char *available_encoders[SUPPORTED_ENCODER_COUNT + 2];
   plugin_node_t *node;
+
 #ifdef HAVE_X11
-  static char *videoout_modes[] = { "letterboxed tv",      "widescreen tv",
+  static const char const *videoout_modes[] = { "letterboxed tv",      "widescreen tv",
 				    "letterboxed overlay", "widescreen overlay", NULL };
 #else
-  static char *videoout_modes[] = { "letterboxed tv", "widescreen tv", NULL };
+  static const char const *videoout_modes[] = { "letterboxed tv", "widescreen tv", NULL };
 #endif
-  static char *tv_modes[] = { "ntsc", "pal", "pal60" , "default", NULL };
-
+  static const char const *tv_modes[] = { "ntsc", "pal", "pal60" , "default", NULL };
+  int list_id, list_size;
+  xine_sarray_t *plugin_list;
+  
   if (class->instance) return NULL;
   
-  this = (dxr3_driver_t *)xine_xmalloc(sizeof(dxr3_driver_t));
+  this = calloc(1, sizeof(dxr3_driver_t));
   if (!this) return NULL;
   
   this->vo_driver.get_capabilities     = dxr3_get_capabilities;
@@ -299,8 +299,11 @@ static vo_driver_t *dxr3_vo_open_plugin(video_driver_class_t *class_gen, const v
 #endif
   /* check, if ffmpeg plugin is available by looking through plugin
    * catalog; catalog mutex is already locked here, since this is open_plugin() */
-  for (node = xine_list_first_content(class->xine->plugin_catalog->video); node;
-       node = xine_list_next_content(class->xine->plugin_catalog->video))
+  node = NULL;
+  plugin_list = class->xine->plugin_catalog->plugin_lists[PLUGIN_VIDEO_DECODER - 1];
+  list_size = xine_sarray_size(plugin_list);
+  for (list_id = 0; list_id < list_size; list_id++) {
+    node = xine_sarray_get (plugin_list, list_id);
     if (strcasecmp(node->info->id, "ffmpegvideo") == 0) {
       available_encoders[encoder++] = "libavcodec";
 #if LOG_VID
@@ -308,6 +311,7 @@ static vo_driver_t *dxr3_vo_open_plugin(video_driver_class_t *class_gen, const v
 #endif
       break;
     }
+  }
 #ifdef HAVE_LIBFAME
   available_encoders[encoder++] = "fame";
 #if LOG_VID
@@ -333,7 +337,7 @@ static vo_driver_t *dxr3_vo_open_plugin(video_driver_class_t *class_gen, const v
 	"this setting can be \"fame\", \"rte\", \"libavcodec\" or \"none\".\n"
 	"The \"libavcodec\" encoder makes use of the ffmpeg plugin that already ships with xine, "
 	"so you do not need to install any additional library for that. Even better is that "
-	"libdavcodec also provides high quality with low CPU usage. Using \"libavcodec\" is "
+	"libavcodec also provides high quality with low CPU usage. Using \"libavcodec\" is "
 	"therefore strongly suggested.\n\"fame\" and \"rte\" are still there, "
 	"but xine support for them is outdated, so these might fail to work."),
       0, NULL, NULL);
@@ -427,13 +431,13 @@ static vo_driver_t *dxr3_vo_open_plugin(video_driver_class_t *class_gen, const v
       this->tv_switchable = 1;
       this->widescreen_enabled = confnum - 2;
       confstr = config->register_string(config, "dxr3.output.keycolor", "0x80a040",
-	_("overlay colorkey value"), _("Hexadecimal RGB value of the key color.\n"
+	_("overlay colour key value"), _("Hexadecimal RGB value of the key colour.\n"
 	"You can try different values, if you experience windows becoming transparent "
 	"when using DXR3 overlay mode."), 20, NULL, NULL);
       sscanf(confstr, "%x", &this->overlay.colorkey);
       confstr = config->register_string(config, "dxr3.output.keycolor_interval", "50.0",
-	_("overlay colorkey tolerance"), _("A greater value widens the tolerance for "
-	"the overlay keycolor.\nYou can try lower values, if you experience windows "
+	_("overlay colour key tolerance"), _("A greater value widens the tolerance for "
+	"the overlay key colour.\nYou can try lower values, if you experience windows "
 	"becoming transparent when using DXR3 overlay mode, but parts of the image borders may "
 	"disappear when using a too low setting."), 20, NULL, NULL);
       sscanf(confstr, "%f", &this->overlay.color_interval);
@@ -505,7 +509,7 @@ static vo_driver_t *dxr3_vo_open_plugin(video_driver_class_t *class_gen, const v
     
     if (dxr3_overlay_set_keycolor(&this->overlay) != 0)
       xprintf(this->class->xine, XINE_VERBOSITY_DEBUG, 
-	      "video_out_dxr3: setting the overlay keycolor failed.\n");
+	      "video_out_dxr3: setting the overlay key colour failed.\n");
     if (dxr3_overlay_set_attributes(&this->overlay) != 0)
       xprintf(this->class->xine, XINE_VERBOSITY_DEBUG, 
 	      "video_out_dxr3: setting an overlay attribute failed.\n");
@@ -532,7 +536,7 @@ static vo_frame_t *dxr3_alloc_frame(vo_driver_t *this_gen)
   dxr3_frame_t *frame;
   dxr3_driver_t *this = (dxr3_driver_t *)this_gen;
   
-  frame = (dxr3_frame_t *)xine_xmalloc(sizeof(dxr3_frame_t));
+  frame = calloc(1, sizeof(dxr3_frame_t));
   
   pthread_mutex_init(&frame->vo_frame.mutex, NULL);
 
@@ -728,7 +732,7 @@ static void dxr3_update_frame_format(vo_driver_t *this_gen, vo_frame_t *frame_ge
       /* planar format, only base[0] */
       /* add one extra line for field swap stuff */
       frame->real_base[0] = xine_xmalloc_aligned(16, image_size + frame->vo_frame.pitches[0],
-        (void**)&frame->mem);
+        &frame->mem);
 
       /* don't use first line */
       frame->real_base[0] += frame->vo_frame.pitches[0];
@@ -756,7 +760,7 @@ static void dxr3_update_frame_format(vo_driver_t *this_gen, vo_frame_t *frame_ge
 
       /* add one extra line for field swap stuff */
       frame->real_base[0] = xine_xmalloc_aligned(16, image_size_y + frame->vo_frame.pitches[0] +
-        image_size_u + image_size_v, (void**)&frame->mem);
+        image_size_u + image_size_v, &frame->mem);
 
       /* don't use first line */
       frame->real_base[0] += frame->vo_frame.pitches[0];
@@ -804,6 +808,9 @@ static void dxr3_overlay_begin(vo_driver_t *this_gen, vo_frame_t *frame_gen, int
   
   this->spu_enc->need_reencode = 1;
   this->spu_enc->overlay = NULL;
+  
+  this->alphablend_extra_data.offset_x = frame_gen->overlay_offset_x;
+  this->alphablend_extra_data.offset_y = frame_gen->overlay_offset_y;
 }
 
 static void dxr3_overlay_blend(vo_driver_t *this_gen, vo_frame_t *frame_gen,
@@ -816,11 +823,11 @@ static void dxr3_overlay_blend(vo_driver_t *this_gen, vo_frame_t *frame_gen,
     
     if (overlay->rle) {
       if (frame_gen->format == XINE_IMGFMT_YV12)
-        blend_yuv(frame->vo_frame.base, overlay,
+        _x_blend_yuv(frame->vo_frame.base, overlay,
                   frame->vo_frame.width, frame->vo_frame.height,
                   frame->vo_frame.pitches, &this->alphablend_extra_data);
       else
-        blend_yuy2(frame->vo_frame.base[0], overlay,
+        _x_blend_yuy2(frame->vo_frame.base[0], overlay,
                    frame->vo_frame.width, frame->vo_frame.height,
                    frame->vo_frame.pitches[0], &this->alphablend_extra_data);
     }
@@ -872,10 +879,10 @@ static void dxr3_overlay_end(vo_driver_t *this_gen, vo_frame_t *frame_gen)
   }
   
   /* copy clip palette */
-  this->spu_enc->color[4] = this->spu_enc->clip_color[0];
-  this->spu_enc->color[5] = this->spu_enc->clip_color[1];
-  this->spu_enc->color[6] = this->spu_enc->clip_color[2];
-  this->spu_enc->color[7] = this->spu_enc->clip_color[3];
+  this->spu_enc->color[4] = this->spu_enc->hili_color[0];
+  this->spu_enc->color[5] = this->spu_enc->hili_color[1];
+  this->spu_enc->color[6] = this->spu_enc->hili_color[2];
+  this->spu_enc->color[7] = this->spu_enc->hili_color[3];
   /* set palette */
   if (ioctl(this->fd_spu, EM8300_IOCTL_SPU_SETPALETTE, this->spu_enc->color))
     xprintf(this->class->xine, XINE_VERBOSITY_DEBUG, 
@@ -888,18 +895,18 @@ static void dxr3_overlay_end(vo_driver_t *this_gen, vo_frame_t *frame_gen)
 	    "video_out_dxr3: spu device write failed (%s)\n", strerror(errno));
   else if (written != this->spu_enc->size)
     xprintf(this->class->xine, XINE_VERBOSITY_DEBUG, 
-	    "video_out_dxr3: Could only write %d of %d spu bytes.\n", written, this->spu_enc->size);
+	    "video_out_dxr3: Could only write %zd of %d spu bytes.\n", written, this->spu_enc->size);
   /* set clipping */
   btn.color = 0x7654;
   btn.contrast =
-    ((this->spu_enc->clip_trans[3] << 12) & 0xf000) |
-    ((this->spu_enc->clip_trans[2] <<  8) & 0x0f00) |
-    ((this->spu_enc->clip_trans[1] <<  4) & 0x00f0) |
-    ((this->spu_enc->clip_trans[0]      ) & 0x000f);
-  btn.left   = this->spu_enc->overlay->x + this->spu_enc->overlay->clip_left;
-  btn.right  = this->spu_enc->overlay->x + this->spu_enc->overlay->clip_right - 1;
-  btn.top    = this->spu_enc->overlay->y + this->spu_enc->overlay->clip_top;
-  btn.bottom = this->spu_enc->overlay->y + this->spu_enc->overlay->clip_bottom - 2;
+    ((this->spu_enc->hili_trans[3] << 12) & 0xf000) |
+    ((this->spu_enc->hili_trans[2] <<  8) & 0x0f00) |
+    ((this->spu_enc->hili_trans[1] <<  4) & 0x00f0) |
+    ((this->spu_enc->hili_trans[0]      ) & 0x000f);
+  btn.left   = this->spu_enc->overlay->x + this->spu_enc->overlay->hili_left;
+  btn.right  = this->spu_enc->overlay->x + this->spu_enc->overlay->hili_right - 1;
+  btn.top    = this->spu_enc->overlay->y + this->spu_enc->overlay->hili_top;
+  btn.bottom = this->spu_enc->overlay->y + this->spu_enc->overlay->hili_bottom - 2;
   if (ioctl(this->fd_spu, EM8300_IOCTL_SPU_BUTTON, &btn))
     xprintf(this->class->xine, XINE_VERBOSITY_DEBUG, 
 	    "dxr3_decode_spu: failed to set spu button (%s)\n", strerror(errno));
@@ -1201,7 +1208,7 @@ static int dxr3_gui_data_exchange(vo_driver_t *this_gen, int data_type, void *da
     break;
   case XINE_GUI_SEND_VIDEOWIN_VISIBLE:
     {
-      int window_showing = (int)data;
+      long window_showing = (long)data;
       int val;
       if (!window_showing) {
         llprintf(LOG_VID, "Hiding video window and diverting video to TV\n");
@@ -1238,7 +1245,7 @@ static void dxr3_dispose(vo_driver_t *this_gen)
   close(this->fd_control);
   pthread_mutex_lock(&this->spu_device_lock);
   if (this->fd_spu) {
-    uint8_t empty_spu[] = {
+    static const uint8_t empty_spu[] = {
       0x00, 0x26, 0x00, 0x08, 0x80, 0x00, 0x00, 0x80,
       0x00, 0x00, 0x00, 0x20, 0x01, 0x03, 0x00, 0x00,
       0x04, 0x00, 0x00, 0x05, 0x00, 0x00, 0x01, 0x00,
@@ -1327,7 +1334,7 @@ static int lookup_parameter(struct lut_entry *lut, char *name,
 static int dxr3_overlay_read_state(dxr3_overlay_t *this)
 {
   char *loc;
-  char fname[256], tmp[128], line[256];
+  char *fname, line[256];
   FILE *fp;
   struct lut_entry lut[] = {
     {"xoffset",        TYPE_INT,   &this->xoffset},
@@ -1352,18 +1359,16 @@ static int dxr3_overlay_read_state(dxr3_overlay_t *this)
    * (used by .overlay/res file) */
   setlocale(LC_NUMERIC, "C");
 
-  snprintf(tmp, sizeof(tmp), "/res_%dx%dx%d",
+  asprintf(&fname, "%s/.overlay/res_%dx%dx%d", getenv("HOME"), 
     this->screen_xres, this->screen_yres, this->screen_depth);
-  strncpy(fname, getenv("HOME"), sizeof(fname) - strlen(tmp) - sizeof("/.overlay"));
-  fname[sizeof(fname) - strlen(tmp) - sizeof("/.overlay")] = '\0';
-  strcat(fname, "/.overlay");
-  strcat(fname, tmp);
   llprintf(LOG_OVR, "attempting to open %s\n", fname);
   if (!(fp = fopen(fname, "r"))) {
     xprintf(this->xine, XINE_VERBOSITY_LOG, 
 	    _("video_out_dxr3: ERROR Reading overlay init file. Run autocal!\n"));
+    free(fname);
     return -1;
   }
+  free(fname);
 
   while (!feof(fp)) {
     if (!fgets(line, 256, fp))
